pub struct Vector3 {
pub x: f64,
pub y: f64,
pub z: f64,
}Expand description
A three-dimensional vector.
Examples
use use_vector::Vector3;
let vector = Vector3::new(2.0, 3.0, 6.0);
assert_eq!(vector.magnitude(), 7.0);Fields
x: f64The x component.
y: f64The y component.
z: f64The z component.
Implementations
Sourceimpl Vector3
impl Vector3
Sourcepub fn magnitude_squared(self) -> f64
pub fn magnitude_squared(self) -> f64
Returns the squared Euclidean magnitude.
Sourcepub fn normalize(self) -> Option<Self>
pub fn normalize(self) -> Option<Self>
Returns a normalized vector when the magnitude is finite and non-zero.
Returns None for zero vectors or vectors with non-finite magnitude.
Sourcepub fn distance_squared(self, other: Self) -> f64
pub fn distance_squared(self, other: Self) -> f64
Returns the squared Euclidean distance to other.